@@ -8,7 +8,7 @@ use Carp;
 use LWP;
 use WWW::Scroogle::Result;
 
-our $VERSION = '0.0132_001';
+our $VERSION = '0.0131';
 
 sub new
 {
@@ -386,12 +386,6 @@ returns the position (counting from 1) of the first result whose url matches the
 
 returns a list of the positions (counting from 1) of all results whose url's are matching the given string or regexp
 
-=head1 CREDITS
-
-Tina Müller
-
-Moritz Lenz
-
 =head1 AUTHOR
 
 Written by Lars Hartmann, <lars (at) chaotika (dot) org>.
